==> styled-bootstrap-0.1.7-0.tgz: package/lib/Progress/ProgressBar.js <==
var _templateObject = _taggedTemplateLiteral(['\n  from { background-position: ', ' 0; }\n  to { background-position: 0 0; }\n'], ['\n  from { background-position: ', ' 0; }\n  to { background-position: 0 0; }\n']),
    _templateObject2 = _taggedTemplateLiteral(['\n  height: ', ';\n  width: ', ';\n  line-height: ', ';\n  color: ', ';\n  background-color: ', ';\n  ', ';\n\n  ', ';\n\n  ', ';\n'], ['\n  height: ', ';\n  width: ', ';\n  line-height: ', ';\n  color: ', ';\n  background-color: ', ';\n  ', ';\n\n  ', ';\n\n  ', ';\n']),
    _templateObject3 = _taggedTemplateLiteral(['\n      ', '\n      background-size:\n        ', '\n        ', ';\n  '], ['\n      ', '\n      background-size:\n        ', '\n        ', ';\n  ']),
    _templateObject4 = _taggedTemplateLiteral(['\n      animation: ', '\n        ', ';\n    '], ['\n      animation: ', '\n        ', ';\n    ']);

function _taggedTemplateLiteral(strings, raw) { return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

import styled, { css, keyframes } from 'styled-components';
import { gradientStriped } from '../utils/src/gradients';
import { transition } from '../utils/src/transition';

import themeProp from '../utils/src/theme';

import { progressHeight, progressBarColor, progressBarBg, progressBarAnimationTiming, progressBarTransition } from './default-theme';

var progressBarStripes = keyframes(_templateObject, progressHeight);

var ProgressBar = styled.div.attrs({
  role: 'progressbar'
})(_templateObject2, themeProp('progressHeight', progressHeight), function (props) {
  return props.width;
}, themeProp('progressHeight', progressHeight), themeProp('progressBarColor', progressBarColor), themeProp('progressBarBg', progressBarBg), transition(themeProp('progressBarTransition', progressBarTransition)), function (props) {
  return props.striped && css(_templateObject3, gradientStriped(), themeProp('progressHeight', progressHeight), themeProp('progressHeight', progressHeight));
}, function (props) {
  return props.animated && css(_templateObject4, progressBarStripes, themeProp('progressBarAnimationTiming', progressBarAnimationTiming));
});

ProgressBar.defaultProps = {};

export default ProgressBar;

==> styled-bootstrap-0.1.9.tgz: package/lib/Progress/ProgressBar.js <==
var _templateObject = _taggedTemplateLiteral(['\n  from { background-position: ', ' 0; }\n  to { background-position: 0 0; }\n'], ['\n  from { background-position: ', ' 0; }\n  to { background-position: 0 0; }\n']),
    _templateObject2 = _taggedTemplateLiteral(['\n  height: ', ';\n  width: ', ';\n  line-height: ', ';\n  color: ', ';\n  background-color: ', ';\n  ', ';\n\n  ', ';\n\n  ', ';\n'], ['\n  height: ', ';\n  width: ', ';\n  line-height: ', ';\n  color: ', ';\n  background-color: ', ';\n  ', ';\n\n  ', ';\n\n  ', ';\n']),
    _templateObject3 = _taggedTemplateLiteral(['\n      ', '\n      background-size:\n        ', '\n        ', ';\n  '], ['\n      ', '\n      background-size:\n        ', '\n        ', ';\n  ']),
    _templateObject4 = _taggedTemplateLiteral(['\n      animation: ', '\n        ', ';\n    '], ['\n      animation: ', '\n        ', ';\n    ']);

function _taggedTemplateLiteral(strings, raw) { return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

import styled, { css, keyframes } from 'styled-components';
import { gradientStriped } from '../utils/gradients';
import { transition } from '../utils/transition';

import themeProp from '../utils/theme';

import { progressHeight, progressBarColor, progressBarBg, progressBarAnimationTiming, progressBarTransition } from './default-theme';

var progressBarStripes = keyframes(_templateObject, progressHeight);

var ProgressBar = styled.div.attrs({
  role: 'progressbar'
})(_templateObject2, themeProp('progressHeight', progressHeight), function (props) {
  return props.width;
}, themeProp('progressHeight', progressHeight), themeProp('progressBarColor', progressBarColor), themeProp('progressBarBg', progressBarBg), transition(themeProp('progressBarTransition', progressBarTransition)), function (props) {
  return props.striped && css(_templateObject3, gradientStriped(), themeProp('progressHeight', progressHeight), themeProp('progressHeight', progressHeight));
}, function (props) {
  return props.animated && css(_templateObject4, progressBarStripes, themeProp('progressBarAnimationTiming', progressBarAnimationTiming));
});

ProgressBar.defaultProps = {};

export default ProgressBar;
